# {name} — Lab Instructions

## Goal

Improve the pipeline code in {pipeline_dir}/ to minimize the evaluation score.

## Context

<!-- Describe what the pipeline does, what the score measures, and any domain
     knowledge that helps the agent make better changes. -->

## Constraints

<!-- List any constraints the agent should follow, e.g.:
     - Do not add external dependencies
     - Keep latency under 500ms
     - Only modify files in a specific subdirectory -->
